player = {
	x = 0,
	y = 0,

	w = 16,
	h = 24,

	xvel = 0,
	yvel = 0,
	friction = 10,

	speed = 1000
}

function player:spawn(x, y, xvel, yvel)
	self.x = x
	self.y = y

	self.xvel = self.xvel or 0
	self.yvel = self.yvel or 0
	camera:load(x, y)
end

--[[ movement ]]--

-- Adds velocity dependent on User's input
function player:addVelocity(dt)
	if love.keyboard.isDown("w") then
		self.yvel = self.yvel - self.speed * dt
	end
	if love.keyboard.isDown("a") then
		self.xvel = self.xvel - self.speed * dt
	end
	if love.keyboard.isDown("s") then
		self.yvel = self.yvel + self.speed * dt
	end
	if love.keyboard.isDown("d") then
		self.xvel = self.xvel + self.speed * dt
	end
end

-- Limitiert die maximale Geschwindichkeit
function player:speedLimit()
	self.xvel = math.max(self.xvel, -self.speed)
	self.xvel = math.min(self.xvel, self.speed)

	self.yvel = math.max(self.yvel, -self.speed)
	self.yvel = math.min(self.yvel, self.speed)
end

-- Modifies velocity by friction
function player:modByFriction(dt)
	self.xvel = self.xvel * (1 - math.min(dt * self.friction, 1))
	self.yvel = self.yvel * (1 - math.min(dt * self.friction, 1))
end

-- Bewegt den character
function player:movement(dt)
	self.x = self.x + self.xvel * dt
	self.y = self.y + self.yvel * dt

	if mapIO.map.orientation == "isometric" then
		-- adjust z value
		-- check the tile under players position

		-- add to list
		local x, y = xymod[mapIO.map.orientation](player.x, player.y)
		table.insert(mapIO["isometric"].mapData, {id = "player", x = x, y = y, z = z})
	end
end

function player:update(dt)
	-- movement
	player:addVelocity(dt)
	player:speedLimit()
	player:modByFriction(dt)
	player:movement(dt)
end

function player:draw()
	love.graphics.setColor(255, 0, 0)
	local x, y = xymod[mapIO.map.orientation](player.x, player.y)
	love.graphics.rectangle("fill", x, y, self.w, self.h)
end